@@ -103,18 +103,19 @@ class CollectionIndex(ICollectionIndex, Database):
 
     # ### catalog ###
 
-    def insert_catalog(self, name, src, path, deletable, branch_name, close=True):
+    def insert_catalog(self, name, src, path, deletable, branch_name, catalog_type, close=True):
         next_id = self.next_id("catalog")
         cursor = self.get_cursor()
 
         cursor.execute(
-            "INSERT INTO catalog VALUES (?, ?, ?, ?, ?, ?)",
+            "INSERT INTO catalog VALUES (?, ?, ?, ?, ?, ?, ?)",
             (
                 next_id,
                 name,
                 src,
                 path,
                 branch_name,
+                catalog_type,
                 deletable
             )
         )
@@ -651,24 +652,46 @@ class CollectionIndex(ICollectionIndex, Database):
 
     def insert_collection_collection(self, collection_id_parent, collection_id_child, catalog_id_parent,
                                      catalog_id_child, close=True):
-        solution_solution_id = self.next_id("collection_collection")
 
-        cursor = self.get_cursor()
-        cursor.execute(
-            "INSERT INTO collection_collection values (?, ?, ?, ?, ?)",
-            (
-                solution_solution_id,
-                collection_id_parent,
-                collection_id_child,
-                catalog_id_parent,
-                catalog_id_child
+
+        if not self._exists_collection_collection(collection_id_parent, collection_id_child, catalog_id_parent,
+                                                  catalog_id_child, close=False):
+
+            solution_solution_id = self.next_id("collection_collection")
+
+            cursor = self.get_cursor()
+            cursor.execute(
+                "INSERT INTO collection_collection values (?, ?, ?, ?, ?)",
+                (
+                    solution_solution_id,
+                    collection_id_parent,
+                    collection_id_child,
+                    catalog_id_parent,
+                    catalog_id_child
+                )
             )
-        )
+        if close:
+            self.close_current_connection()
+
+    def _exists_collection_collection(self, collection_id_parent, collection_id_child, catalog_id_parent,
+                                                  catalog_id_child, close=True):
+        cursor = self.get_cursor()
+        r = cursor.execute(
+            "SELECT * FROM collection_collection WHERE collection_id_parent=:collection_id_parent "
+            "AND collection_id_child=:collection_id_child AND catalog_id_parent=:catalog_id_parent "
+            "AND catalog_id_child=:catalog_id_child",
+            {
+                "collection_id_parent": collection_id_parent,
+                "collection_id_child": collection_id_child,
+                "catalog_id_parent": catalog_id_parent,
+                "catalog_id_child": catalog_id_child
+            }
+        ).fetchone()
 
         if close:
             self.close_current_connection()
 
-        return solution_solution_id
+        return r["collection_collection_id"] if r else None
 
     def remove_parent(self, collection_id, close=True):
         cursor = self.get_cursor()
@@ -1020,6 +1043,62 @@ class CollectionIndex(ICollectionIndex, Database):
 
         return solutions_list
 
+    def get_solutions_by_grp_name(self, group: str, name: str, close=True) -> List[CollectionSolution]:
+        solutions_list = []
+
+        cursor = self.get_cursor()
+        for row in cursor.execute(
+                "SELECT * FROM collection WHERE \"group\"=:group AND name=:name",
+                {
+                    "group": group,
+                    "name": name
+                }
+        ).fetchall():
+            solution = self._process_solution_row(dict(row), close=False)
+            solutions_list.append(solution)
+
+        if close:
+            self.close_current_connection()
+
+        return solutions_list
+
+    def get_solutions_by_name_version(self, name: str, version: str, close=True) -> List[CollectionSolution]:
+        solutions_list = []
+
+        cursor = self.get_cursor()
+        for row in cursor.execute(
+                "SELECT * FROM collection WHERE name=:name AND version=:version",
+                {
+                    "name": name,
+                    "version": version,
+                }
+        ).fetchall():
+            solution = self._process_solution_row(dict(row), close=False)
+            solutions_list.append(solution)
+
+        if close:
+            self.close_current_connection()
+
+        return solutions_list
+
+    def get_solutions_by_name(self, name: str, close=True) -> List[CollectionSolution]:
+        solutions_list = []
+
+        cursor = self.get_cursor()
+        for row in cursor.execute(
+                "SELECT * FROM collection WHERE name=:name",
+                {
+                    "name": name
+                }
+        ).fetchall():
+            solution = self._process_solution_row(dict(row), close=False)
+            solutions_list.append(solution)
+
+        if close:
+            self.close_current_connection()
+
+        return solutions_list
+
     def get_recently_installed_solutions(self, close=True) -> List[CollectionSolution]:
         solutions_list = []
 
@@ -1214,7 +1293,7 @@ class CollectionIndex(ICollectionIndex, Database):
 
     @staticmethod
     def _as_db_col(key):
-        if key is "group":
+        if key == "group":
             return "\"group\""
         return key
 
